@@ -118,9 +118,9 @@ class Cache:
         self._callbacks2: dict[
             str, list[tuple[Callable[..., Any], tuple[Any, ...], dict[Any, Any]]]
         ] = {}  # noqa
-        self._weakref: weakref.WeakValueDictionary[
-            str, apt.Package
-        ] = weakref.WeakValueDictionary()  # noqa
+        self._weakref: weakref.WeakValueDictionary[str, apt.Package] = (
+            weakref.WeakValueDictionary()
+        )  # noqa
         self._weakversions: weakref.WeakSet[Version] = weakref.WeakSet()  # noqa
         self._changes_count = -1
         self._sorted_set: list[str] | None = None
@@ -140,9 +140,10 @@ class Cache:
             apt_pkg.config.set("Dir::State::status", rootdir + "/var/lib/dpkg/status")
             # also set dpkg to the rootdir path so that its called for the
             # --print-foreign-architectures call
-            apt_pkg.config.set(
-                "Dir::bin::dpkg", os.path.join(rootdir, "usr", "bin", "dpkg")
-            )
+            if os.path.exists(os.path.join(rootdir, "usr", "bin", "dpkg")):
+                apt_pkg.config.set(
+                    "Dir::bin::dpkg", os.path.join(rootdir, "usr", "bin", "dpkg")
+                )
             # create required dirs/files when run with special rootdir
             # automatically
             self._check_and_create_required_dirs(rootdir)
@@ -176,6 +177,8 @@ class Cache:
         dirs = [
             "/var/lib/dpkg",
             "/etc/apt/",
+            "/etc/apt/apt.conf.d",
+            "/etc/apt/preferences.d",
             "/var/cache/apt/archives/partial",
             "/var/lib/apt/lists/partial",
         ]
@@ -812,6 +815,12 @@ class ProblemResolver:
         self._resolver.resolve_by_keep()
         self._cache.cache_post_change()
 
+    def keep_phased_updates(self) -> None:
+        """Keep back phased updates."""
+        self._cache.cache_pre_change()
+        self._resolver.keep_phased_updates()
+        self._cache.cache_post_change()
+
 
 # ----------------------------- experimental interface
 
