@@ -11,11 +11,12 @@
 #   config.py -no-h -- -help       ; Turn off help, specify the file '-help'
 # -c and -o are standard APT-program options.
 
+import posixpath
+import sys
+
 # This shows how to use the system for configuration and option control.
 # The other varient is for ISC object config files. See configisc.py.
 import apt_pkg
-import sys
-import posixpath
 
 # Create a new empty Configuration object - there is also the system global
 # configuration object apt_pkg.config which is used interally by apt-pkg
@@ -56,4 +57,4 @@ print("No help for you, try -h")
 # Print the configuration space
 print("The Configuration space looks like:")
 for item in list(Cnf.keys()):
-    print('%s "%s";' % (item, Cnf[item]))
+    print(f'{item} "{Cnf[item]}";')
