@@ -222,6 +222,7 @@ class TestAptCache(testcommon.TestCase):
         apt_pkg.config.set("dir::etc::sourcelist", old_source_list)
         apt_pkg.config.set("dir::etc::sourceparts", old_source_parts)
 
+    @if_sources_list_is_readable
     def test_package_cmp(self):
         cache = apt.Cache(rootdir="/")
         li = []
@@ -236,6 +237,18 @@ class TestAptCache(testcommon.TestCase):
         arches = apt_pkg.get_architectures()
         self.assertTrue(main_arch in arches)
 
+    def test_phasing_applied(self):
+        """checks the return type of phasing_applied."""
+        cache = apt.Cache()
+        pkg = cache["apt"]
+        self.assertIsInstance(pkg.phasing_applied, bool)
+
+    def test_is_security_update(self):
+        """checks the return type of is_security_update."""
+        cache = apt.Cache()
+        pkg = cache["apt"]
+        self.assertIsInstance(pkg.installed.is_security_update, bool)
+
     def test_apt_cache_reopen_is_safe(self):
         """cache: check that we cannot use old package objects after reopen"""
         cache = apt.Cache()
@@ -371,6 +384,18 @@ class TestAptCache(testcommon.TestCase):
             c["a"].mark_delete()
             self.assertEqual([c["a"]], [p for p in c if p.marked_delete])
 
+    def test_problemresolver_keep_phased_updates(self):
+        """Check that the c++ function can be called."""
+        with tempfile.NamedTemporaryFile() as status:
+            apt_pkg.config["Dir::Etc::SourceList"] = "/dev/null"
+            apt_pkg.config["Dir::Etc::SourceParts"] = "/dev/null"
+            apt_pkg.config["Dir::State::Status"] = status.name
+            apt_pkg.init_system()
+
+            cache = apt.Cache()
+            problemresolver = apt.ProblemResolver(cache)
+            self.assertIsNone(problemresolver.keep_phased_updates())
+
 
 if __name__ == "__main__":
     unittest.main()
