@@ -12,7 +12,6 @@ import shutil
 import sys
 import unittest
 
-
 from test_all import get_library_dir
 
 libdir = get_library_dir()
@@ -20,9 +19,10 @@ if libdir:
     sys.path.insert(0, libdir)
 
 import apt_pkg
-import apt
 import testcommon
 
+import apt
+
 
 class TestSourceRecords(testcommon.TestCase):
     def setUp(self):
@@ -32,7 +32,7 @@ class TestSourceRecords(testcommon.TestCase):
         if os.path.exists(rootdir):
             shutil.rmtree(rootdir)
         try:
-            os.makedirs(os.path.join(rootdir, "etc", "apt"))
+            os.makedirs(os.path.join(rootdir, "etc", "apt", "apt.conf.d"))
         except OSError:
             pass
 
